DynamicTableController class
Controller for programmatic interaction with DynamicTableScrollView.
- Inheritance
-
- Object
- ChangeNotifier
- DynamicTableController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateToHorizontal(
double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) → Future< void> -
Animates horizontally to a target
offset. -
animateToRow(
int rowIndex, {double rowHeight = 48.0, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) → Future< void> - Animates vertically to a specific row index.
-
animateToVertical(
double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) → Future< void> -
Animates vertically to a target
offset. -
attach(
{LinkedScrollGroup? verticalGroup, LinkedScrollGroup? horizontalGroup, ScrollController? verticalController, ScrollController? horizontalController}) → void -
Internal attachment called by
DynamicTableScrollViewState. -
detach(
) → void -
Internal detachment called by
DynamicTableScrollViewState. -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
jumpToHorizontal(
double offset) → void -
Scrolls horizontally to a target
offset. -
jumpToRow(
int rowIndex, {double rowHeight = 48.0}) → void - Jumps vertically to a specific row index based on the given row height.
-
jumpToVertical(
double offset) → void -
Scrolls vertically to a target
offset. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited